import { createApi, fetchBaseQuery } from '@reduxjs/toolkit/query/react';

export const dataApi = createApi({
    reducerPath: 'dataApi',
    baseQuery: fetchBaseQuery({ baseUrl: './data' }),
    endpoints: builder => ({
        getDataByName: builder.query({
            query: name => `${name}.json`,
            transformResponse: response => {
                return {
                    resources: response.resources.rows,
                    events: response.events.rows,
                    timeRanges: response.timeRanges.rows
                };
            },
            async onCacheEntryAdded(arg, { updateCachedData, cacheDataLoaded, cacheEntryRemoved }) {
                try {
                    // wait for the initial query to resolve before proceeding
                    await cacheDataLoaded;
        
            // when data is received from the socket connection to the server,
            // if it is a message and for the appropriate channel,
            // update our query result with the received message
            const newData = /* import here youre new dataset */
            setTimeout(() => {
                updateCachedData((draft) => {
                return [newData];
                }, 5000);
                });
        
            } catch (e) {
            console.log(e);
            // no-op in case `cacheEntryRemoved` resolves before `cacheDataLoaded`,
            // in which case `cacheDataLoaded` will throw
            }
            // cacheEntryRemoved will resolve when the cache subscription is no longer active
            await cacheEntryRemoved;
            // perform cleanup steps once the `cacheEntryRemoved` promise resolves
      },
        })
    })
});

export const { useGetDataByNameQuery } = dataApi;
